"""Task Manager API main application file."""
import uvicorn
from fastapi import APIRouter, FastAPI
from fastapi.middleware.cors import CORSMiddleware

from app.api.v1.endpoints import tasks
from app.core.config import settings

app = FastAPI(
    title=settings.PROJECT_NAME,
    description=settings.PROJECT_DESCRIPTION,
    version=settings.VERSION,
    openapi_url="/openapi.json",
    docs_url="/docs",
    redoc_url="/redoc",
)

# Configure CORS
app.add_middleware(
    CORSMiddleware,
    allow_origins=["*"],
    allow_credentials=True,
    allow_methods=["*"],
    allow_headers=["*"],
)

# Create API router for v1
api_v1_router = APIRouter(prefix="/api/v1")

# Add tasks endpoints directly to v1 router
api_v1_router.include_router(tasks.router, prefix="/tasks", tags=["tasks"])

# Include API v1 router in main app
app.include_router(api_v1_router)


@app.get("/", tags=["Root"])
async def root():
    """Root endpoint that returns basic information about the API."""
    return {
        "title": settings.PROJECT_NAME,
        "docs": "/docs",
        "health": "/health",
    }


@app.get("/health", tags=["Health"])
async def health_check():
    """Health check endpoint."""
    return {"status": "healthy"}


if __name__ == "__main__":
    uvicorn.run("main:app", host="0.0.0.0", port=8000, reload=True)